@@ -245,8 +245,11 @@ class Minion(
     def _handle_signals(self, signum, sigframe):  # pylint: disable=unused-argument
         # escalate signal to the process manager processes
         if hasattr(self.minion, "stop"):
-            self.minion.stop(signum)
-        super()._handle_signals(signum, sigframe)
+            # If the minion has a stop method, call it - this is the case for
+            # MinionManager
+            self.minion.stop(signum, super()._handle_signals)
+        else:
+            super()._handle_signals(signum, sigframe)
 
     # pylint: disable=no-member
     def prepare(self):
@@ -425,7 +428,7 @@ class ProxyMinion(
 
     def _handle_signals(self, signum, sigframe):  # pylint: disable=unused-argument
         # escalate signal to the process manager processes
-        self.minion.stop(signum)
+        self.minion.stop(signum, super()._handle_signals)
         super()._handle_signals(signum, sigframe)
 
     # pylint: disable=no-member
