@@ -2,20 +2,20 @@
 A collection of mixins useful for the various *Client interfaces
 """
 
-
-import copy as pycopy
+import copy
 import fnmatch
 import logging
+import os
 import signal
 import traceback
 import weakref
 from collections.abc import Mapping, MutableMapping
 
+import salt._logging
+import salt.channel.client
 import salt.exceptions
-import salt.ext.tornado.stack_context
-import salt.log.setup
 import salt.minion
-import salt.transport.client
+import salt.output
 import salt.utils.args
 import salt.utils.doc
 import salt.utils.error
@@ -98,12 +98,14 @@ class ClientFuncsDict(MutableMapping):
 
             user = salt.utils.user.get_specific_user()
             return self.client._proc_function(
-                key,
-                low,
-                user,
-                async_pub["tag"],  # TODO: fix
-                async_pub["jid"],  # TODO: fix
-                False,  # Don't daemonize
+                instance=self.client,
+                opts=self.client.opts,
+                fun=key,
+                low=low,
+                user=user,
+                tag=async_pub["tag"],
+                jid=async_pub["jid"],
+                daemonize=False,
             )
 
         return wrapper
@@ -115,7 +117,26 @@ class ClientFuncsDict(MutableMapping):
         return iter(self.client.functions)
 
 
-class SyncClientMixin:
+class ClientStateMixin:
+    def __init__(self, opts, context=None):
+        self.opts = opts
+        if context is None:
+            context = {}
+        self.context = context
+
+    # __setstate__ and __getstate__ are only used on spawning platforms.
+    def __getstate__(self):
+        return {
+            "opts": self.opts,
+            "context": self.context or None,
+        }
+
+    def __setstate__(self, state):
+        # If __setstate__ is getting called it means this is running on a new process.
+        self.__init__(state["opts"], context=state["context"])
+
+
+class SyncClientMixin(ClientStateMixin):
     """
     A mixin for *Client interfaces to abstract common function execution
     """
@@ -137,7 +158,7 @@ class SyncClientMixin:
         load = kwargs
         load["cmd"] = self.client
 
-        with salt.transport.client.ReqChannel.factory(
+        with salt.channel.client.ReqChannel.factory(
             self.opts, crypt="clear", usage="master_call"
         ) as channel:
             ret = channel.send(load)
@@ -192,31 +213,6 @@ class SyncClientMixin:
     ):
         """
         Execute a function
-
-        .. code-block:: python
-
-            >>> opts = salt.config.master_config('/etc/salt/master')
-            >>> runner = salt.runner.RunnerClient(opts)
-            >>> runner.cmd('jobs.list_jobs', [])
-            {
-                '20131219215650131543': {
-                    'Arguments': [300],
-                    'Function': 'test.sleep',
-                    'StartTime': '2013, Dec 19 21:56:50.131543',
-                    'Target': '*',
-                    'Target-type': 'glob',
-                    'User': 'saltdev'
-                },
-                '20131219215921857715': {
-                    'Arguments': [300],
-                    'Function': 'test.sleep',
-                    'StartTime': '2013, Dec 19 21:59:21.857715',
-                    'Target': '*',
-                    'Target-type': 'glob',
-                    'User': 'saltdev'
-                },
-            }
-
         """
         if arg is None:
             arg = tuple()
@@ -249,6 +245,8 @@ class SyncClientMixin:
             self.functions[fun], arglist, pub_data
         )
         low = {"fun": fun, "arg": args, "kwarg": kwargs}
+        if "user" in pub_data:
+            low["__user__"] = pub_data["user"]
         return self.low(fun, low, print_event=print_event, full_return=full_return)
 
     @property
@@ -274,7 +272,7 @@ class SyncClientMixin:
             return True
 
         try:
-            return self.opts["{}_returns".format(class_name)]
+            return self.opts[f"{class_name}_returns"]
         except KeyError:
             # No such option, assume this isn't one we care about gating and
             # just return True.
@@ -301,7 +299,7 @@ class SyncClientMixin:
         tag = low.get("__tag__", salt.utils.event.tagify(jid, prefix=self.tag_prefix))
 
         data = {
-            "fun": "{}.{}".format(self.client, fun),
+            "fun": f"{self.client}.{fun}",
             "jid": jid,
             "user": low.get("__user__", "UNKNOWN"),
         }
@@ -319,7 +317,6 @@ class SyncClientMixin:
             salt.utils.event.get_event(
                 "master",
                 self.opts["sock_dir"],
-                self.opts["transport"],
                 opts=self.opts,
                 listen=False,
             ),
@@ -339,7 +336,7 @@ class SyncClientMixin:
             }
 
             try:
-                self_functions = pycopy.copy(self.functions)
+                self_functions = copy.copy(self.functions)
                 salt.utils.lazy.verify_fun(self_functions, fun)
 
                 # Inject some useful globals to *all* the function's global
@@ -381,37 +378,36 @@ class SyncClientMixin:
                 data["fun_args"] = list(args) + ([kwargs] if kwargs else [])
                 func_globals["__jid_event__"].fire_event(data, "new")
 
-                # Initialize a context for executing the method.
-                with salt.ext.tornado.stack_context.StackContext(
-                    self.functions.context_dict.clone
-                ):
-                    func = self.functions[fun]
-                    try:
-                        data["return"] = func(*args, **kwargs)
-                    except TypeError as exc:
-                        data[
-                            "return"
-                        ] = "\nPassed invalid arguments: {}\n\nUsage:\n{}".format(
+                func = self.functions[fun]
+                try:
+                    data["return"] = func(*args, **kwargs)
+                except TypeError as exc:
+                    data["return"] = (
+                        "\nPassed invalid arguments: {}\n\nUsage:\n{}".format(
                             exc, func.__doc__
                         )
-                    try:
-                        data["success"] = self.context.get("retcode", 0) == 0
-                    except AttributeError:
-                        # Assume a True result if no context attribute
-                        data["success"] = True
-                    if isinstance(data["return"], dict) and "data" in data["return"]:
-                        # some functions can return boolean values
-                        data["success"] = salt.utils.state.check_result(
-                            data["return"]["data"]
-                        )
+                    )
+                try:
+                    data["success"] = self.context.get("retcode", 0) == 0
+                except AttributeError:
+                    # Assume a True result if no context attribute
+                    data["success"] = True
+                if isinstance(data["return"], dict) and "data" in data["return"]:
+                    # some functions can return boolean values
+                    data["success"] = salt.utils.state.check_result(
+                        data["return"]["data"]
+                    )
             except (Exception, SystemExit) as ex:  # pylint: disable=broad-except
                 if isinstance(ex, salt.exceptions.NotImplemented):
                     data["return"] = str(ex)
                 else:
                     data["return"] = "Exception occurred in {} {}: {}".format(
-                        self.client, fun, traceback.format_exc(),
+                        self.client,
+                        fun,
+                        traceback.format_exc(),
                     )
                 data["success"] = False
+                data["retcode"] = 1
 
             if self.store_job:
                 try:
@@ -470,7 +466,7 @@ class SyncClientMixin:
         return salt.utils.doc.strip_rst(docs)
 
 
-class AsyncClientMixin:
+class AsyncClientMixin(ClientStateMixin):
     """
     A mixin for *Client interfaces to enable easy asynchronous function execution
     """
@@ -478,50 +474,76 @@ class AsyncClientMixin:
     client = None
     tag_prefix = None
 
-    def _proc_function_remote(self, fun, low, user, tag, jid, daemonize=True):
+    @classmethod
+    def _proc_function_remote(
+        cls, *, instance, opts, fun, low, user, tag, jid, daemonize=True
+    ):
         """
         Run this method in a multiprocess target to execute the function on the
         master and fire the return data on the event bus
         """
-        if daemonize and not salt.utils.platform.is_windows():
-            # Shutdown the multiprocessing before daemonizing
-            salt.log.setup.shutdown_multiprocessing_logging()
-
+        if daemonize and not salt.utils.platform.spawning_platform():
+            # Shutdown logging before daemonizing
+            salt._logging.shutdown_logging()
             salt.utils.process.daemonize()
-
-            # Reconfigure multiprocessing logging after daemonizing
-            salt.log.setup.setup_multiprocessing_logging()
+            # Because we have daemonized, salt._logging.in_mainprocess() will
+            # return False. We'll just force it to return True for this
+            # particular case so that proper logging can be set up.
+            salt._logging.in_mainprocess.__pid__ = os.getpid()
+            # Configure logging once daemonized
+            salt._logging.setup_logging()
 
         # pack a few things into low
         low["__jid__"] = jid
         low["__user__"] = user
         low["__tag__"] = tag
 
+        if instance is None:
+            instance = cls(opts)
+
         try:
-            return self.cmd_sync(low)
+            return instance.cmd_sync(low)
         except salt.exceptions.EauthAuthenticationError as exc:
             log.error(exc)
 
-    def _proc_function(self, fun, low, user, tag, jid, daemonize=True):
+    @classmethod
+    def _proc_function(
+        cls,
+        *,
+        instance,
+        opts,
+        fun,
+        low,
+        user,
+        tag,
+        jid,
+        daemonize=True,
+        full_return=False,
+    ):
         """
         Run this method in a multiprocess target to execute the function
         locally and fire the return data on the event bus
         """
-        if daemonize and not salt.utils.platform.is_windows():
-            # Shutdown the multiprocessing before daemonizing
-            salt.log.setup.shutdown_multiprocessing_logging()
-
+        if daemonize and not salt.utils.platform.spawning_platform():
+            # Shutdown logging before daemonizing
+            salt._logging.shutdown_logging()
             salt.utils.process.daemonize()
+            # Because we have daemonized, salt._logging.in_mainprocess() will
+            # return False. We'll just force it to return True for this
+            # particular case so that proper logging can be set up.
+            salt._logging.in_mainprocess.__pid__ = os.getpid()
+            # Configure logging once daemonized
+            salt._logging.setup_logging()
 
-            # Reconfigure multiprocessing logging after daemonizing
-            salt.log.setup.setup_multiprocessing_logging()
+        if instance is None:
+            instance = cls(opts)
 
         # pack a few things into low
         low["__jid__"] = jid
         low["__user__"] = user
         low["__tag__"] = tag
 
-        return self.low(fun, low)
+        return instance.low(fun, low, full_return=full_return)
 
     def cmd_async(self, low):
         """
@@ -559,14 +581,26 @@ class AsyncClientMixin:
         else:
             proc_func = self._proc_function_remote
         async_pub = pub if pub is not None else self._gen_async_pub()
-        proc = salt.utils.process.SignalHandlingProcess(
-            target=proc_func,
-            name="ProcessFunc",
-            args=(fun, low, user, async_pub["tag"], async_pub["jid"]),
-        )
+        if salt.utils.platform.spawning_platform():
+            instance = None
+        else:
+            instance = self
         with salt.utils.process.default_signals(signal.SIGINT, signal.SIGTERM):
-            # Reset current signals before starting the process in
-            # order not to inherit the current signal handlers
+            proc = salt.utils.process.SignalHandlingProcess(
+                target=proc_func,
+                name="ProcessFunc({}, fun={} jid={})".format(
+                    proc_func.__qualname__, fun, async_pub["jid"]
+                ),
+                kwargs=dict(
+                    instance=instance,
+                    opts=self.opts,
+                    fun=fun,
+                    low=low,
+                    user=user,
+                    tag=async_pub["tag"],
+                    jid=async_pub["jid"],
+                ),
+            )
             proc.start()
         proc.join()  # MUST join, otherwise we leave zombies all over
         return async_pub
