@@ -2,10 +2,8 @@
 Detect LVM Volumes
 """
 
-# Import python libs
 import logging
 
-# Import salt libs
 import salt.modules.cmdmod
 import salt.utils.files
 import salt.utils.path
@@ -35,15 +33,13 @@ def _linux_lvm():
     ret = {}
     cmd = salt.utils.path.which("lvm")
     if cmd:
-        vgs = __salt__["cmd.run"]("{} vgs -o vg_name --noheadings".format(cmd))
+        vgs = __salt__["cmd.run_all"](f"{cmd} vgs -o vg_name --noheadings")
 
-        for vg in vgs.splitlines():
+        for vg in vgs["stdout"].splitlines():
             vg = vg.strip()
             ret[vg] = []
-            lvs = __salt__["cmd.run"](
-                "{} lvs -o lv_name --noheadings {}".format(cmd, vg)
-            )
-            for lv in lvs.splitlines():
+            lvs = __salt__["cmd.run_all"](f"{cmd} lvs -o lv_name --noheadings {vg}")
+            for lv in lvs["stdout"].splitlines():
                 ret[vg].append(lv.strip())
 
         return {"lvm": ret}
@@ -54,11 +50,11 @@ def _linux_lvm():
 def _aix_lvm():
     ret = {}
     cmd = salt.utils.path.which("lsvg")
-    vgs = __salt__["cmd.run"]("{}".format(cmd))
+    vgs = __salt__["cmd.run"](f"{cmd}")
 
     for vg in vgs.splitlines():
         ret[vg] = []
-        lvs = __salt__["cmd.run"]("{} -l {}".format(cmd, vg))
+        lvs = __salt__["cmd.run"](f"{cmd} -l {vg}")
         for lvline in lvs.splitlines()[2:]:
             lv = lvline.split(" ", 1)[0]
             ret[vg].append(lv)
