@@ -72,7 +72,7 @@ def _cert_file(name, cert_type):
     """
     Return expected path of a Let's Encrypt live cert
     """
-    return os.path.join(LE_LIVE, name, "{}.pem".format(cert_type))
+    return os.path.join(LE_LIVE, name, f"{cert_type}.pem")
 
 
 def _expires(name):
@@ -88,9 +88,9 @@ def _expires(name):
         expiry = __salt__["tls.cert_info"](cert_file).get("not_after", 0)
     # Cobble it together using the openssl binary
     else:
-        openssl_cmd = "openssl x509 -in {} -noout -enddate".format(cert_file)
+        openssl_cmd = f"openssl x509 -in {cert_file} -noout -enddate"
         # No %e format on my Linux'es here
-        strptime_sux_cmd = 'date --date="$({} | cut -d= -f2)" +%s'.format(openssl_cmd)
+        strptime_sux_cmd = f'date --date="$({openssl_cmd} | cut -d= -f2)" +%s'
         expiry = float(__salt__["cmd.shell"](strptime_sux_cmd, output_loglevel="quiet"))
         # expiry = datetime.datetime.strptime(expiry.split('=', 1)[-1], '%b %e %H:%M:%S %Y %Z')
     return datetime.datetime.fromtimestamp(expiry)
@@ -132,6 +132,8 @@ def cert(
     http_01_address=None,
     dns_plugin=None,
     dns_plugin_credentials=None,
+    manual_auth_hook=None,
+    manual_cleanup_hook=None,
 ):
     """
     Obtain/renew a certificate from an ACME CA, probably Let's Encrypt.
@@ -168,6 +170,8 @@ def cert(
         the specified DNS plugin
     :param dns_plugin_propagate_seconds: Number of seconds to wait for DNS propogations
         before asking ACME servers to verify the DNS record. (default 10)
+    :param manual_auth_hook: Path to the manual authentication hook script.
+    :param manual_cleanup_hook: Path to the manual cleanup or post-authentication hook script.
     :rtype: dict
     :return: Dictionary with 'result' True/False/None, 'comment' and certificate's
         expiry date ('not_after')
@@ -195,10 +199,10 @@ def cert(
         cmd.append("--renew-by-default")
         renew = True
     if server:
-        cmd.append("--server {}".format(server))
+        cmd.append(f"--server {server}")
 
     if certname:
-        cmd.append("--cert-name {}".format(certname))
+        cmd.append(f"--cert-name {certname}")
 
     if test_cert:
         if server:
@@ -211,41 +215,46 @@ def cert(
     if webroot:
         cmd.append("--authenticator webroot")
         if webroot is not True:
-            cmd.append("--webroot-path {}".format(webroot))
+            cmd.append(f"--webroot-path {webroot}")
     elif dns_plugin in supported_dns_plugins:
         if dns_plugin == "cloudflare":
             cmd.append("--dns-cloudflare")
-            cmd.append("--dns-cloudflare-credentials {}".format(dns_plugin_credentials))
+            cmd.append(f"--dns-cloudflare-credentials {dns_plugin_credentials}")
         else:
             return {
                 "result": False,
-                "comment": "DNS plugin '{}' is not supported".format(dns_plugin),
+                "comment": f"DNS plugin '{dns_plugin}' is not supported",
             }
+    elif manual_auth_hook:
+        cmd.append("--manual")
+        cmd.append(f"--manual-auth-hook '{manual_auth_hook}'")
+        if manual_cleanup_hook:
+            cmd.append(f"--manual-cleanup-hook '{manual_cleanup_hook}'")
     else:
         cmd.append("--authenticator standalone")
 
     if email:
-        cmd.append("--email {}".format(email))
+        cmd.append(f"--email {email}")
 
     if keysize:
-        cmd.append("--rsa-key-size {}".format(keysize))
+        cmd.append(f"--rsa-key-size {keysize}")
 
-    cmd.append("--domains {}".format(name))
+    cmd.append(f"--domains {name}")
     if aliases is not None:
         for dns in aliases:
-            cmd.append("--domains {}".format(dns))
+            cmd.append(f"--domains {dns}")
 
     if preferred_challenges:
-        cmd.append("--preferred-challenges {}".format(preferred_challenges))
+        cmd.append(f"--preferred-challenges {preferred_challenges}")
 
     if tls_sni_01_port:
-        cmd.append("--tls-sni-01-port {}".format(tls_sni_01_port))
+        cmd.append(f"--tls-sni-01-port {tls_sni_01_port}")
     if tls_sni_01_address:
-        cmd.append("--tls-sni-01-address {}".format(tls_sni_01_address))
+        cmd.append(f"--tls-sni-01-address {tls_sni_01_address}")
     if http_01_port:
-        cmd.append("--http-01-port {}".format(http_01_port))
+        cmd.append(f"--http-01-port {http_01_port}")
     if http_01_address:
-        cmd.append("--http-01-address {}".format(http_01_address))
+        cmd.append(f"--http-01-address {http_01_address}")
 
     res = __salt__["cmd.run_all"](" ".join(cmd))
 
@@ -269,13 +278,13 @@ def cert(
             }
 
     if "no action taken" in res["stdout"]:
-        comment = "Certificate {} unchanged".format(cert_file)
+        comment = f"Certificate {cert_file} unchanged"
         result = None
     elif renew:
-        comment = "Certificate {} renewed".format(certname)
+        comment = f"Certificate {certname} renewed"
         result = True
     else:
-        comment = "Certificate {} obtained".format(certname)
+        comment = f"Certificate {certname} obtained"
         result = True
 
     ret = {
@@ -339,7 +348,7 @@ def info(name):
         cert_info = __salt__["x509.read_certificate"](cert_file)
     else:
         # Cobble it together using the openssl binary
-        openssl_cmd = "openssl x509 -in {} -noout -text".format(cert_file)
+        openssl_cmd = f"openssl x509 -in {cert_file} -noout -text"
         cert_info = {"text": __salt__["cmd.run"](openssl_cmd, output_loglevel="quiet")}
     return cert_info
 
