@@ -48,7 +48,6 @@ Module to provide Elasticsearch compatibility to Salt
     Some functionality might be limited by elasticsearch-py and Elasticsearch server versions.
 """
 
-
 import logging
 
 from salt.exceptions import CommandExecutionError, SaltInvocationError
@@ -203,9 +202,8 @@ def info(hosts=None, profile=None):
         return es.info()
     except elasticsearch.TransportError as e:
         raise CommandExecutionError(
-            "Cannot retrieve server information, server returned code {} with message {}".format(
-                e.status_code, e.error
-            )
+            "Cannot retrieve server information, server returned code {} with"
+            " message {}".format(e.status_code, e.error)
         )
 
 
@@ -263,9 +261,8 @@ def cluster_health(index=None, level="cluster", local=False, hosts=None, profile
         return es.cluster.health(index=index, level=level, local=local)
     except elasticsearch.TransportError as e:
         raise CommandExecutionError(
-            "Cannot retrieve health information, server returned code {} with message {}".format(
-                e.status_code, e.error
-            )
+            "Cannot retrieve health information, server returned code {} with"
+            " message {}".format(e.status_code, e.error)
         )
 
 
@@ -397,9 +394,8 @@ def alias_create(indices, alias, hosts=None, body=None, profile=None, source=Non
         return result.get("acknowledged", False)
     except elasticsearch.TransportError as e:
         raise CommandExecutionError(
-            "Cannot create alias {} in index {}, server returned code {} with message {}".format(
-                alias, indices, e.status_code, e.error
-            )
+            "Cannot create alias {} in index {}, server returned code {} with"
+            " message {}".format(alias, indices, e.status_code, e.error)
         )
 
 
@@ -434,9 +430,8 @@ def alias_delete(indices, aliases, hosts=None, body=None, profile=None, source=N
         return True
     except elasticsearch.TransportError as e:
         raise CommandExecutionError(
-            "Cannot delete alias {} in index {}, server returned code {} with message {}".format(
-                aliases, indices, e.status_code, e.error
-            )
+            "Cannot delete alias {} in index {}, server returned code {} with"
+            " message {}".format(aliases, indices, e.status_code, e.error)
         )
 
 
@@ -532,9 +527,8 @@ def document_create(
         return es.index(index=index, doc_type=doc_type, body=body, id=id)
     except elasticsearch.TransportError as e:
         raise CommandExecutionError(
-            "Cannot create document in index {}, server returned code {} with message {}".format(
-                index, e.status_code, e.error
-            )
+            "Cannot create document in index {}, server returned code {} with"
+            " message {}".format(index, e.status_code, e.error)
         )
 
 
@@ -563,9 +557,8 @@ def document_delete(index, doc_type, id, hosts=None, profile=None):
         return None
     except elasticsearch.TransportError as e:
         raise CommandExecutionError(
-            "Cannot delete document {} in index {}, server returned code {} with message {}".format(
-                id, index, e.status_code, e.error
-            )
+            "Cannot delete document {} in index {}, server returned code {} with"
+            " message {}".format(id, index, e.status_code, e.error)
         )
 
 
@@ -594,9 +587,8 @@ def document_exists(index, id, doc_type="_all", hosts=None, profile=None):
         return False
     except elasticsearch.TransportError as e:
         raise CommandExecutionError(
-            "Cannot retrieve document {} from index {}, server returned code {} with message {}".format(
-                id, index, e.status_code, e.error
-            )
+            "Cannot retrieve document {} from index {}, server returned code {} with"
+            " message {}".format(id, index, e.status_code, e.error)
         )
 
 
@@ -625,9 +617,8 @@ def document_get(index, id, doc_type="_all", hosts=None, profile=None):
         return None
     except elasticsearch.TransportError as e:
         raise CommandExecutionError(
-            "Cannot retrieve document {} from index {}, server returned code {} with message {}".format(
-                id, index, e.status_code, e.error
-            )
+            "Cannot retrieve document {} from index {}, server returned code {} with"
+            " message {}".format(id, index, e.status_code, e.error)
         )
 
 
@@ -1597,7 +1588,8 @@ def snapshot_get(
         )
     except elasticsearch.TransportError as e:
         raise CommandExecutionError(
-            "Cannot obtain details of snapshot {} in repository {}, server returned code {} with message {}".format(
+            "Cannot obtain details of snapshot {} in repository {}, server returned"
+            " code {} with message {}".format(
                 snapshot, repository, e.status_code, e.error
             )
         )
@@ -1632,9 +1624,8 @@ def snapshot_create(repository, snapshot, body=None, hosts=None, profile=None):
         return response.get("accepted", False)
     except elasticsearch.TransportError as e:
         raise CommandExecutionError(
-            "Cannot create snapshot {} in repository {}, server returned code {} with message {}".format(
-                snapshot, repository, e.status_code, e.error
-            )
+            "Cannot create snapshot {} in repository {}, server returned code {} with"
+            " message {}".format(snapshot, repository, e.status_code, e.error)
         )
 
 
@@ -1667,9 +1658,8 @@ def snapshot_restore(repository, snapshot, body=None, hosts=None, profile=None):
         return response.get("accepted", False)
     except elasticsearch.TransportError as e:
         raise CommandExecutionError(
-            "Cannot restore snapshot {} in repository {}, server returned code {} with message {}".format(
-                snapshot, repository, e.status_code, e.error
-            )
+            "Cannot restore snapshot {} in repository {}, server returned code {} with"
+            " message {}".format(snapshot, repository, e.status_code, e.error)
         )
 
 
@@ -1700,9 +1690,8 @@ def snapshot_delete(repository, snapshot, hosts=None, profile=None):
         return True
     except elasticsearch.TransportError as e:
         raise CommandExecutionError(
-            "Cannot delete snapshot {} from repository {}, server returned code {} with message {}".format(
-                snapshot, repository, e.status_code, e.error
-            )
+            "Cannot delete snapshot {} from repository {}, server returned code {} with"
+            " message {}".format(snapshot, repository, e.status_code, e.error)
         )
 
 
