@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 #
 # Copyright 2015 SUSE LLC
 #
@@ -14,14 +13,11 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-# Import Python Libs
-from __future__ import absolute_import
 
 import logging
 import os
 import time
 
-# Import Salt Libs
 import salt.utils.files
 import salt.utils.fsutils
 import salt.utils.network
@@ -32,14 +28,14 @@ from salt.modules.inspectlib.exceptions import InspectorQueryException, SIExcept
 log = logging.getLogger(__name__)
 
 
-class SysInfo(object):
+class SysInfo:
     """
     System information.
     """
 
     def __init__(self, systype):
         if systype.lower() == "solaris":
-            raise SIException("Platform {0} not (yet) supported.".format(systype))
+            raise SIException(f"Platform {systype} not (yet) supported.")
 
     def _grain(self, grain):
         """
@@ -51,15 +47,15 @@ class SysInfo(object):
         """
         Get a size of a disk.
         """
-        out = __salt__["cmd.run_all"]("df {0}".format(device))
+        out = __salt__["cmd.run_all"](f"df {device}")
         if out["retcode"]:
-            msg = "Disk size info error: {0}".format(out["stderr"])
+            msg = "Disk size info error: {}".format(out["stderr"])
             log.error(msg)
             raise SIException(msg)
 
-        devpath, blocks, used, available, used_p, mountpoint = [
+        devpath, blocks, used, available, used_p, mountpoint = (
             elm for elm in out["stdout"].split(os.linesep)[-1].split(" ") if elm
-        ]
+        )
         return {
             "device": devpath,
             "blocks": blocks,
@@ -78,7 +74,7 @@ class SysInfo(object):
         for dev, dev_data in salt.utils.fsutils._blkid().items():
             dev = self._get_disk_size(dev)
             device = dev.pop("device")
-            dev["type"] = dev_data["type"]
+            dev["type"] = dev_data.get("type", "UNKNOWN")
             data[device] = dev
 
         return data
@@ -110,7 +106,7 @@ class SysInfo(object):
         """
         out = __salt__["cmd.run_all"]("vmstat -s")
         if out["retcode"]:
-            raise SIException("Memory info error: {0}".format(out["stderr"]))
+            raise SIException("Memory info error: {}".format(out["stderr"]))
 
         ret = dict()
         for line in out["stdout"].split(os.linesep):
@@ -182,13 +178,13 @@ class Query(EnvLoader):
         """
         if scope and scope not in self.SCOPES:
             raise InspectorQueryException(
-                "Unknown scope: {0}. Must be one of: {1}".format(
+                "Unknown scope: {}. Must be one of: {}".format(
                     repr(scope), ", ".join(self.SCOPES)
                 )
             )
         elif not scope:
             raise InspectorQueryException(
-                "Scope cannot be empty. Must be one of: {0}".format(
+                "Scope cannot be empty. Must be one of: {}".format(
                     ", ".join(self.SCOPES)
                 )
             )
@@ -468,13 +464,13 @@ class Query(EnvLoader):
 
             fmt = fmt.lower()
             if fmt == "b":
-                return "{0} Bytes".format(size)
+                return f"{size} Bytes"
             elif fmt == "kb":
-                return "{0} Kb".format(round((float(size) / 0x400), 2))
+                return f"{round((float(size) / 0x400), 2)} Kb"
             elif fmt == "mb":
-                return "{0} Mb".format(round((float(size) / 0x400 / 0x400), 2))
+                return f"{round((float(size) / 0x400 / 0x400), 2)} Mb"
             elif fmt == "gb":
-                return "{0} Gb".format(round((float(size) / 0x400 / 0x400 / 0x400), 2))
+                return f"{round((float(size) / 0x400 / 0x400 / 0x400), 2)} Gb"
 
         filter = kwargs.get("filter")
         offset = kwargs.get("offset", 0)
@@ -482,25 +478,27 @@ class Query(EnvLoader):
         timeformat = kwargs.get("time", "tz")
         if timeformat not in ["ticks", "tz"]:
             raise InspectorQueryException(
-                'Unknown "{0}" value for parameter "time"'.format(timeformat)
+                f'Unknown "{timeformat}" value for parameter "time"'
+            )
+
+        def tfmt(param):
+            return (
+                timeformat == "tz"
+                and time.strftime("%b %d %Y %H:%M:%S", time.gmtime(param))
+                or int(param)
             )
-        tfmt = (
-            lambda param: timeformat == "tz"
-            and time.strftime("%b %d %Y %H:%M:%S", time.gmtime(param))
-            or int(param)
-        )
 
         size_fmt = kwargs.get("size")
         if size_fmt is not None and size_fmt.lower() not in ["b", "kb", "mb", "gb"]:
             raise InspectorQueryException(
-                'Unknown "{0}" value for parameter "size". '
+                'Unknown "{}" value for parameter "size". '
                 "Should be either B, Kb, Mb or Gb".format(timeformat)
             )
 
         owners = kwargs.get("owners", "id")
         if owners not in ["name", "id"]:
             raise InspectorQueryException(
-                'Unknown "{0}" value for parameter "owners". '
+                'Unknown "{}" value for parameter "owners". '
                 "Should be either name or id (default)".format(owners)
             )
 
@@ -511,7 +509,7 @@ class Query(EnvLoader):
         for i_type in incl_type:
             if i_type not in ["directory", "dir", "d", "file", "f", "link", "l"]:
                 raise InspectorQueryException(
-                    'Unknown "{0}" values for parameter "type". '
+                    'Unknown "{}" values for parameter "type". '
                     "Should be comma separated one or more of "
                     "dir, file and/or link.".format(", ".join(incl_type))
                 )
@@ -529,9 +527,9 @@ class Query(EnvLoader):
                 pld_files.append(pld_data.path)
             else:
                 pld_files[pld_data.path] = {
-                    "uid": self._id_resolv(pld_data.uid, named=(owners == "id")),
+                    "uid": self._id_resolv(pld_data.uid, named=owners == "id"),
                     "gid": self._id_resolv(
-                        pld_data.gid, named=(owners == "id"), uid=False
+                        pld_data.gid, named=owners == "id", uid=False
                     ),
                     "size": _size_format(pld_data.p_size, fmt=size_fmt),
                     "mode": oct(pld_data.mode),
