@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 """
 Wrapper around Server Density API
 =================================
@@ -6,21 +5,13 @@ Wrapper around Server Density API
 .. versionadded:: 2014.7.0
 """
 
-# Import Python libs
-from __future__ import absolute_import, print_function, unicode_literals
-
 import logging
 import os
 import tempfile
 
-# Import Salt libs
 import salt.utils.json
 from salt.exceptions import CommandExecutionError
 
-# Import 3rd-party libs
-from salt.ext import six
-from salt.ext.six.moves import map
-
 try:
     import requests
 
@@ -57,14 +48,14 @@ def get_sd_auth(val, sd_auth_pillar_name="serverdensity"):
     if not sd_pillar:
         log.error("Could not load %s pillar", sd_auth_pillar_name)
         raise CommandExecutionError(
-            "{0} pillar is required for authentication".format(sd_auth_pillar_name)
+            f"{sd_auth_pillar_name} pillar is required for authentication"
         )
 
     try:
         return sd_pillar[val]
     except KeyError:
         log.error("Could not find value %s in pillar", val)
-        raise CommandExecutionError("{0} value was not found in pillar".format(val))
+        raise CommandExecutionError(f"{val} value was not found in pillar")
 
 
 def _clean_salt_variables(params, variable_prefix="__"):
@@ -97,6 +88,7 @@ def create(name, **params):
         "https://api.serverdensity.io/inventory/devices/",
         params={"token": get_sd_auth("api_token")},
         data=params,
+        timeout=120,
     )
     log.debug("Server Density API Response: %s", api_response)
     log.debug("Server Density API Response content: %s", api_response.content)
@@ -106,7 +98,7 @@ def create(name, **params):
         except ValueError:
             log.error("Could not parse API Response content: %s", api_response.content)
             raise CommandExecutionError(
-                "Failed to create, API Response: {0}".format(api_response)
+                f"Failed to create, API Response: {api_response}"
             )
     else:
         return None
@@ -128,6 +120,7 @@ def delete(device_id):
     api_response = requests.delete(
         "https://api.serverdensity.io/inventory/devices/" + device_id,
         params={"token": get_sd_auth("api_token")},
+        timeout=120,
     )
     log.debug("Server Density API Response: %s", api_response)
     log.debug("Server Density API Response content: %s", api_response.content)
@@ -137,7 +130,7 @@ def delete(device_id):
         except ValueError:
             log.error("Could not parse API Response content: %s", api_response.content)
             raise CommandExecutionError(
-                "Failed to create, API Response: {0}".format(api_response)
+                f"Failed to create, API Response: {api_response}"
             )
     else:
         return None
@@ -170,15 +163,16 @@ def ls(**params):
         endpoint = "resources"
 
     # Convert all ints to strings:
-    for key, val in six.iteritems(params):
-        params[key] = six.text_type(val)
+    for key, val in params.items():
+        params[key] = str(val)
 
     api_response = requests.get(
-        "https://api.serverdensity.io/inventory/{0}".format(endpoint),
+        f"https://api.serverdensity.io/inventory/{endpoint}",
         params={
             "token": get_sd_auth("api_token"),
             "filter": salt.utils.json.dumps(params),
         },
+        timeout=120,
     )
     log.debug("Server Density API Response: %s", api_response)
     log.debug("Server Density API Response content: %s", api_response.content)
@@ -191,9 +185,7 @@ def ls(**params):
                 api_response.content,
             )
             raise CommandExecutionError(
-                "Failed to create, Server Density API Response: {0}".format(
-                    api_response
-                )
+                f"Failed to create, Server Density API Response: {api_response}"
             )
     else:
         return None
@@ -219,6 +211,7 @@ def update(device_id, **params):
         "https://api.serverdensity.io/inventory/devices/" + device_id,
         params={"token": get_sd_auth("api_token")},
         data=params,
+        timeout=120,
     )
     log.debug("Server Density API Response: %s", api_response)
     log.debug("Server Density API Response content: %s", api_response.content)
@@ -231,7 +224,7 @@ def update(device_id, **params):
                 api_response.content,
             )
             raise CommandExecutionError(
-                "Failed to create, API Response: {0}".format(api_response)
+                f"Failed to create, API Response: {api_response}"
             )
     else:
         return None
@@ -265,10 +258,8 @@ def install_agent(agent_key, agent_version=1):
 
     account = get_sd_auth(account_field)
 
-    __salt__["cmd.run"](
-        cmd="curl -L {0} -o {1}".format(url, install_filename), cwd=work_dir
-    )
-    __salt__["cmd.run"](cmd="chmod +x {0}".format(install_filename), cwd=work_dir)
+    __salt__["cmd.run"](cmd=f"curl -L {url} -o {install_filename}", cwd=work_dir)
+    __salt__["cmd.run"](cmd=f"chmod +x {install_filename}", cwd=work_dir)
 
     return __salt__["cmd.run"](
         cmd="{filename} -a {account} -k {agent_key}".format(
