@@ -40,7 +40,6 @@ Module for Sending Messages via SMTP
 
 """
 
-
 import logging
 import os
 import socket
@@ -51,10 +50,10 @@ log = logging.getLogger(__name__)
 
 HAS_LIBS = False
 try:
-    import smtplib
-    import email.mime.text
     import email.mime.application
     import email.mime.multipart
+    import email.mime.text
+    import smtplib
 
     HAS_LIBS = True
 except ImportError:
@@ -133,18 +132,14 @@ def send_msg(
             try:
                 smtpconn.starttls()
             except smtplib.SMTPHeloError:
-                log.debug(
-                    "The server didn’t reply properly \
-                        to the HELO greeting."
-                )
+                log.debug("The server didn’t reply properly to the HELO greeting.")
                 return False
             except smtplib.SMTPException:
                 log.debug("The server does not support the STARTTLS extension.")
                 return False
             except RuntimeError:
                 log.debug(
-                    "SSL/TLS support is not available \
-                        to your Python interpreter."
+                    "SSL/TLS support is not available to your Python interpreter."
                 )
                 return False
             smtpconn.ehlo()
@@ -161,7 +156,7 @@ def send_msg(
             name = os.path.basename(f)
             with salt.utils.files.fopen(f, "rb") as fin:
                 att = email.mime.application.MIMEApplication(fin.read(), Name=name)
-            att["Content-Disposition"] = 'attachment; filename="{}"'.format(name)
+            att["Content-Disposition"] = f'attachment; filename="{name}"'
             msg.attach(att)
 
     try:
