@@ -2,7 +2,6 @@
 Module for managing timezone on POSIX-like systems.
 """
 
-
 import errno
 import filecmp
 import logging
@@ -16,6 +15,7 @@ import salt.utils.itertools
 import salt.utils.path
 import salt.utils.platform
 import salt.utils.stringutils
+from salt.config import DEFAULT_HASH_TYPE
 from salt.exceptions import CommandExecutionError, SaltInvocationError
 
 log = logging.getLogger(__name__)
@@ -117,12 +117,11 @@ def _get_zone_etc_localtime():
             if "FreeBSD" in __grains__["os_family"]:
                 return get_zonecode()
             log.warning(
-                "%s is not a symbolic link. Attempting to match "
-                "it to zoneinfo files.",
+                "%s is not a symbolic link. Attempting to match it to zoneinfo files.",
                 tzfile,
             )
             # Regular file. Try to match the hash.
-            hash_type = __opts__.get("hash_type", "md5")
+            hash_type = __opts__.get("hash_type", DEFAULT_HASH_TYPE)
             tzfile_hash = salt.utils.hashutils.get_hash(tzfile, hash_type)
             # Not a link, just a copy of the tzdata file
             for root, dirs, files in salt.utils.path.os_walk(tzdir):
@@ -145,7 +144,7 @@ def _get_zone_etc_timezone():
             return salt.utils.stringutils.to_unicode(fp_.read()).strip()
     except OSError as exc:
         raise CommandExecutionError(
-            "Problem reading timezone file {}: {}".format(tzfile, exc.strerror)
+            f"Problem reading timezone file {tzfile}: {exc.strerror}"
         )
 
 
@@ -188,11 +187,10 @@ def get_zone():
             except AttributeError:
                 pass
 
-        msg = (
+        raise CommandExecutionError(
             "Failed to parse timedatectl output: {}\n"
-            "Please file an issue with SaltStack"
-        ).format(ret["stdout"])
-        raise CommandExecutionError(msg)
+            "Please file an issue with SaltStack".format(ret["stdout"])
+        )
 
     else:
         if __grains__["os"].lower() == "centos":
@@ -242,7 +240,7 @@ def get_offset():
     salt_path = "/opt/salt/bin/date"
 
     if not os.path.exists(salt_path):
-        return "date in salt binaries does not exist: {}".format(salt_path)
+        return f"date in salt binaries does not exist: {salt_path}"
 
     return __salt__["cmd.run"]([salt_path, "+%z"], python_shell=False)
 
@@ -275,24 +273,24 @@ def set_zone(timezone):
     """
     if salt.utils.path.which("timedatectl"):
         try:
-            __salt__["cmd.run"]("timedatectl set-timezone {}".format(timezone))
+            __salt__["cmd.run"](f"timedatectl set-timezone {timezone}")
         except CommandExecutionError:
             pass
 
     if "Solaris" in __grains__["os_family"] or "AIX" in __grains__["os_family"]:
-        zonepath = "/usr/share/lib/zoneinfo/{}".format(timezone)
+        zonepath = f"/usr/share/lib/zoneinfo/{timezone}"
     else:
-        zonepath = "/usr/share/zoneinfo/{}".format(timezone)
+        zonepath = f"/usr/share/zoneinfo/{timezone}"
 
     if not os.path.exists(zonepath) and "AIX" not in __grains__["os_family"]:
-        return "Zone does not exist: {}".format(zonepath)
+        return f"Zone does not exist: {zonepath}"
 
     tzfile = _get_localtime_path()
     if os.path.exists(tzfile):
         os.unlink(tzfile)
 
     if "Solaris" in __grains__["os_family"]:
-        __salt__["file.sed"]("/etc/default/init", "^TZ=.*", "TZ={}".format(timezone))
+        __salt__["file.sed"]("/etc/default/init", "^TZ=.*", f"TZ={timezone}")
     elif "AIX" in __grains__["os_family"]:
         # timezone could be Olson or Posix
         curtzstring = get_zone()
@@ -309,12 +307,10 @@ def set_zone(timezone):
         os.symlink(zonepath, tzfile)
 
     if "RedHat" in __grains__["os_family"]:
-        __salt__["file.sed"](
-            "/etc/sysconfig/clock", "^ZONE=.*", 'ZONE="{}"'.format(timezone)
-        )
+        __salt__["file.sed"]("/etc/sysconfig/clock", "^ZONE=.*", f'ZONE="{timezone}"')
     elif "Suse" in __grains__["os_family"]:
         __salt__["file.sed"](
-            "/etc/sysconfig/clock", "^TIMEZONE=.*", 'TIMEZONE="{}"'.format(timezone)
+            "/etc/sysconfig/clock", "^TIMEZONE=.*", f'TIMEZONE="{timezone}"'
         )
     elif "Debian" in __grains__["os_family"] or "Gentoo" in __grains__["os_family"]:
         with salt.utils.files.fopen("/etc/timezone", "w") as ofh:
@@ -335,7 +331,7 @@ def zone_compare(timezone):
 
     .. note::
 
-        On Solaris-link operating systems only a string comparison is done.
+        On Solaris-like operating systems only a string comparison is done.
 
     .. versionchanged:: 2016.11.4
 
@@ -352,7 +348,7 @@ def zone_compare(timezone):
     if "Solaris" in __grains__["os_family"] or "AIX" in __grains__["os_family"]:
         return timezone == get_zone()
 
-    if "FreeBSD" in __grains__["os_family"]:
+    if "Arch" in __grains__["os_family"] or "FreeBSD" in __grains__["os_family"]:
         if not os.path.isfile(_get_localtime_path()):
             return timezone == get_zone()
 
@@ -363,9 +359,7 @@ def zone_compare(timezone):
     except OSError as exc:
         problematic_file = exc.filename
         if problematic_file == zonepath:
-            raise SaltInvocationError(
-                'Can\'t find a local timezone "{}"'.format(timezone)
-            )
+            raise SaltInvocationError(f'Can\'t find a local timezone "{timezone}"')
         elif problematic_file == tzfile:
             raise CommandExecutionError(
                 "Failed to read {} to determine current timezone: {}".format(
@@ -385,7 +379,7 @@ def _get_localtime_path():
 
 
 def _get_zone_file(timezone):
-    return "/usr/share/zoneinfo/{}".format(timezone)
+    return f"/usr/share/zoneinfo/{timezone}"
 
 
 def get_hwclock():
@@ -410,11 +404,10 @@ def get_hwclock():
                 except IndexError:
                     pass
 
-        msg = (
+        raise CommandExecutionError(
             "Failed to parse timedatectl output: {}\n"
-            "Please file an issue with SaltStack"
-        ).format(ret["stdout"])
-        raise CommandExecutionError(msg)
+            "Please file an issue with SaltStack".format(ret["stdout"])
+        )
 
     else:
         os_family = __grains__["os_family"]
@@ -456,7 +449,7 @@ def get_hwclock():
                                 if line == "local":
                                     return "LOCAL"
                         raise CommandExecutionError(
-                            "Correct offset value not found in {}".format(offset_file)
+                            f"Correct offset value not found in {offset_file}"
                         )
                 except OSError as exc:
                     raise CommandExecutionError(
@@ -558,10 +551,10 @@ def set_hwclock(clock):
             cmd = ["rtc", "-z", "GMT" if clock.lower() == "utc" else timezone]
             return __salt__["cmd.retcode"](cmd, python_shell=False) == 0
 
-        zonepath = "/usr/share/zoneinfo/{}".format(timezone)
+        zonepath = f"/usr/share/zoneinfo/{timezone}"
 
         if not os.path.exists(zonepath):
-            raise CommandExecutionError("Zone '{}' does not exist".format(zonepath))
+            raise CommandExecutionError(f"Zone '{zonepath}' does not exist")
 
         os.unlink("/etc/localtime")
         os.symlink(zonepath, "/etc/localtime")
@@ -575,13 +568,13 @@ def set_hwclock(clock):
             return __salt__["cmd.retcode"](cmd, python_shell=False) == 0
         elif "RedHat" in __grains__["os_family"]:
             __salt__["file.sed"](
-                "/etc/sysconfig/clock", "^ZONE=.*", 'ZONE="{}"'.format(timezone)
+                "/etc/sysconfig/clock", "^ZONE=.*", f'ZONE="{timezone}"'
             )
         elif "Suse" in __grains__["os_family"]:
             __salt__["file.sed"](
                 "/etc/sysconfig/clock",
                 "^TIMEZONE=.*",
-                'TIMEZONE="{}"'.format(timezone),
+                f'TIMEZONE="{timezone}"',
             )
         elif "Debian" in __grains__["os_family"]:
             if clock == "UTC":
@@ -593,14 +586,10 @@ def set_hwclock(clock):
                 raise SaltInvocationError("Only 'UTC' and 'localtime' are allowed")
             if clock == "localtime":
                 clock = "local"
-            __salt__["file.sed"](
-                "/etc/conf.d/hwclock", "^clock=.*", 'clock="{}"'.format(clock)
-            )
+            __salt__["file.sed"]("/etc/conf.d/hwclock", "^clock=.*", f'clock="{clock}"')
         elif "Slackware" in os_family:
             if clock not in ("UTC", "localtime"):
                 raise SaltInvocationError("Only 'UTC' and 'localtime' are allowed")
-            __salt__["file.sed"](
-                "/etc/hardwareclock", "^(UTC|localtime)", "{}".format(clock)
-            )
+            __salt__["file.sed"]("/etc/hardwareclock", "^(UTC|localtime)", f"{clock}")
 
     return True
