@@ -65,6 +65,15 @@ def _group_changes(cur, wanted, remove=False):
     return bool(remain)
 
 
+def _get_root_args(local):
+    """
+    Retrieve args to use for user.info calls depending on platform and the local flag
+    """
+    if not local or salt.utils.platform.is_windows():
+        return {}
+    return {"root": "/"}
+
+
 def _changes(
     name,
     uid=None,
@@ -97,6 +106,7 @@ def _changes(
     allow_uid_change=False,
     allow_gid_change=False,
     password_lock=None,
+    local=False,
 ):
     """
     Return a dict of the changes required for a user if the user is present,
@@ -112,7 +122,7 @@ def _changes(
     if "shadow.info" in __salt__:
         lshad = __salt__["shadow.info"](name)
 
-    lusr = __salt__["user.info"](name)
+    lusr = __salt__["user.info"](name, **_get_root_args(local))
     if not lusr:
         return False
 
@@ -294,6 +304,7 @@ def present(
     remove_groups=True,
     home=None,
     createhome=True,
+    persist_home=False,
     password=None,
     hash_password=False,
     enforce_password=True,
@@ -321,6 +332,7 @@ def present(
     allow_uid_change=False,
     allow_gid_change=False,
     password_lock=None,
+    local=False,
 ):
     """
     Ensure that the named user is present with the specified properties
@@ -393,6 +405,10 @@ def present(
             Additionally, parent directories will *not* be created. The parent
             directory for ``home`` must already exist.
 
+    persist_home : False
+        If set to ``True`` and not on Windows or Darwin, move contents of the
+        home directory to the new location
+
     nologinit : False
         If set to ``True``, it will not add the user to lastlog and faillog
         databases.
@@ -496,6 +512,12 @@ def present(
         Date that account expires, represented in days since epoch (January 1,
         1970).
 
+    local (Only on systems with luseradd available):
+        Create the user account locally ignoring global account management
+        (default is False).
+
+        .. versionadded:: 3007.0
+
     The below parameters apply to windows only:
 
     win_homedrive (Windows Only)
@@ -661,6 +683,7 @@ def present(
             allow_uid_change,
             allow_gid_change,
             password_lock=password_lock,
+            local=local,
         )
     except CommandExecutionError as exc:
         ret["result"] = False
@@ -683,7 +706,7 @@ def present(
             lshad = __salt__["shadow.info"](name)
         if __grains__["kernel"] in ("OpenBSD", "FreeBSD"):
             lcpre = __salt__["user.get_loginclass"](name)
-        pre = __salt__["user.info"](name)
+        pre = __salt__["user.info"](name, **_get_root_args(local))
 
         # Make changes
 
@@ -716,7 +739,7 @@ def present(
             if __grains__["kernel"] in ("Darwin", "Windows"):
                 __salt__["user.chhome"](name, val)
             else:
-                __salt__["user.chhome"](name, val, persist=False)
+                __salt__["user.chhome"](name, val, persist=persist_home)
 
         _homedir_changed = False
         if "home" in changes:
@@ -787,7 +810,7 @@ def present(
                 "Unhandled changes: {}".format(", ".join(changes))
             )
 
-        post = __salt__["user.info"](name)
+        post = __salt__["user.info"](name, **_get_root_args(local))
         spost = {}
         if "shadow.info" in __salt__ and lshad["passwd"] != password:
             spost = __salt__["shadow.info"](name)
@@ -840,6 +863,7 @@ def present(
             allow_uid_change=True,
             allow_gid_change=True,
             password_lock=password_lock,
+            local=local,
         )
         # allow_uid_change and allow_gid_change passed as True to avoid race
         # conditions where a uid/gid is modified outside of Salt. If an
@@ -882,6 +906,7 @@ def present(
                 "createhome": createhome,
                 "nologinit": nologinit,
                 "loginclass": loginclass,
+                "local": local,
                 "usergroup": usergroup,
             }
         else:
@@ -899,7 +924,7 @@ def present(
         result = __salt__["user.add"](**params)
         if result is True:
             ret["comment"] = f"New user {name} created"
-            ret["changes"] = __salt__["user.info"](name)
+            ret["changes"] = __salt__["user.info"](name, **_get_root_args(local))
             if not createhome:
                 # pwd incorrectly reports presence of home
                 ret["changes"]["home"] = ""
@@ -1037,7 +1062,7 @@ def present(
     return ret
 
 
-def absent(name, purge=False, force=False):
+def absent(name, purge=False, force=False, local=False):
     """
     Ensure that the named user is absent
 
@@ -1052,10 +1077,16 @@ def absent(name, purge=False, force=False):
         If the user is logged in, the absent state will fail. Set the force
         option to True to remove the user even if they are logged in. Not
         supported in FreeBSD and Solaris, Default is ``False``.
+
+    local (Only on systems with luserdel available):
+        Ensure the user account is removed locally ignoring global account management
+        (default is False).
+
+        .. versionadded:: 3007.0
     """
     ret = {"name": name, "changes": {}, "result": True, "comment": ""}
 
-    lusr = __salt__["user.info"](name)
+    lusr = __salt__["user.info"](name, **_get_root_args(local))
     if lusr:
         # The user is present, make it not present
         if __opts__["test"]:
@@ -1063,7 +1094,11 @@ def absent(name, purge=False, force=False):
             ret["comment"] = f"User {name} set for removal"
             return ret
         beforegroups = set(salt.utils.user.get_group_list(name))
-        ret["result"] = __salt__["user.delete"](name, purge, force)
+        if salt.utils.platform.is_windows():
+            del_args = {}
+        else:
+            del_args = {"local": local}
+        ret["result"] = __salt__["user.delete"](name, purge, force, **del_args)
         aftergroups = {g for g in beforegroups if __salt__["group.info"](g)}
         if ret["result"]:
             ret["changes"] = {}
