@@ -2,7 +2,6 @@
 Custom YAML loading in Salt
 """
 
-
 import re
 
 import yaml  # pylint: disable=blacklisted-import
@@ -61,7 +60,7 @@ class SaltYamlSafeLoader(yaml.SafeLoader):
             raise ConstructorError(
                 None,
                 None,
-                "expected a mapping node, but found {}".format(node.id),
+                f"expected a mapping node, but found {node.id}",
                 node.start_mark,
             )
 
@@ -77,7 +76,7 @@ class SaltYamlSafeLoader(yaml.SafeLoader):
                 raise ConstructorError(
                     context,
                     node.start_mark,
-                    "found unacceptable key {}".format(key_node.value),
+                    f"found unacceptable key {key_node.value}",
                     key_node.start_mark,
                 )
             value = self.construct_object(value_node, deep=deep)
@@ -85,7 +84,7 @@ class SaltYamlSafeLoader(yaml.SafeLoader):
                 raise ConstructorError(
                     context,
                     node.start_mark,
-                    "found conflicting ID '{}'".format(key),
+                    f"found conflicting ID '{key}'",
                     key_node.start_mark,
                 )
             mapping[key] = value
